@@ -1,3 +1,6 @@
+#[macro_use]
+extern crate lazy_static;
+
 pub use {notation_model};
 
 #[cfg(feature = "dsl")]
@@ -8,9 +11,6 @@ pub use notation_midi;
 
 pub use {bevy, bevy_prototype_lyon, bevy_egui, bevy_asset_loader};
 
-#[cfg(feature = "inspector")]
-pub use bevy_inspector_egui;
-
 pub mod chord;
 pub mod entry;
 pub mod tone;
@@ -26,12 +26,13 @@ pub mod guitar;
 pub mod kb;
 pub mod lyrics;
 pub mod melody;
+pub mod harmony;
 pub mod rhythm;
 pub mod shapes;
 pub mod strings;
 
 pub mod data;
-pub mod font;
+pub mod egui;
 pub mod settings;
 pub mod theme;
 pub mod notation;
@@ -39,9 +40,6 @@ pub mod notation;
 #[cfg(target_arch = "wasm32")]
 pub mod wasm;
 
-#[cfg(feature = "inspector")]
-pub mod inspector;
-
 #[cfg(feature = "dev")]
 pub mod dev;
 
@@ -83,7 +81,9 @@ pub mod prelude {
     #[doc(hidden)]
     pub use crate::entry::entry_plugin::EntryPlugin;
     #[doc(hidden)]
-    pub use crate::font::font_plugin::FontPlugin;
+    pub use crate::egui::egui_fonts::EguiFontSizes;
+    #[doc(hidden)]
+    pub use crate::egui::egui_plugin::EguiPlugin;
     #[doc(hidden)]
     pub use crate::guitar::guitar_view::GuitarView;
     #[doc(hidden)]
@@ -99,6 +99,10 @@ pub mod prelude {
     #[doc(hidden)]
     pub use crate::melody::melody_plugin::MelodyPlugin;
     #[doc(hidden)]
+    pub use crate::harmony::harmony_grid::HarmonyGrid;
+    #[doc(hidden)]
+    pub use crate::harmony::harmony_plugin::HarmonyPlugin;
+    #[doc(hidden)]
     pub use crate::mini::mini_plugin::MiniPlugin;
     #[doc(hidden)]
     pub use crate::play::play_plugin::PlayPlugin;
@@ -111,7 +115,7 @@ pub mod prelude {
     #[doc(hidden)]
     pub use crate::strings::strings_plugin::StringsPlugin;
     #[doc(hidden)]
-    pub use crate::tab::tab_asset::TabAsset;
+    pub use crate::tab::tab_asset::{TabAsset, TabError};
     #[doc(hidden)]
     pub use crate::tab::tab_bars::TabBars;
     #[doc(hidden)]
@@ -137,9 +141,11 @@ pub mod prelude {
     #[doc(hidden)]
     pub use crate::notation::app::{NotationApp, NotationPlugins};
     #[doc(hidden)]
+    pub use crate::notation::args::{NotationArgs};
+    #[doc(hidden)]
     pub use crate::notation::events::*;
     #[doc(hidden)]
-    pub use crate::notation::state::{NotationState, TabPathes};
+    pub use crate::notation::state::{NotationState};
     #[doc(hidden)]
     pub use crate::notation::assets::{NotationAssets, NotationAssetsStates, ExtraAssets, NoExtraAssets};
     #[doc(hidden)]
