@@ -35,16 +35,11 @@ impl ShapeOp<NotationTheme, StrokeLine> for MiniSectionSeparatorData {
             Vec3::new(line_width + x_offset, 0.0, theme.z.mini_bar + 2.0)
         };
         StrokeLine {
-            from: Vec2::new(
-                0.0,
-                theme.sizes.mini_map.bar_height / 1.0,
-            ),
+            from: Vec2::new(0.0, theme.sizes.mini_map.bar_height / 1.0),
             to: Vec2::new(0.0, -theme.sizes.mini_map.bar_height / 2.0),
             line_width: theme.sizes.mini_map.section_separator,
-            color: theme
-                .colors
-                .of_section(self.bar_props.section_ordinal),
+            color: theme.colors.of_section(self.bar_props.section_ordinal),
             offset,
         }
     }
-}
\ No newline at end of file
+}
