@@ -9,7 +9,7 @@ use super::control::Control;
 
 use crate::prelude::{
     GuitarView, NotationState, NotationSettings, NotationTheme, TabAsset,
-    TabPathes, WindowResizedEvent,
+    NotationArgs, WindowResizedEvent,
 };
 
 #[cfg(feature = "midi")]
@@ -161,6 +161,12 @@ impl ControlPanel {
         CollapsingHeader::new("Display Options")
             .default_open(true)
             .show(ui, |ui| {
+                let mut hide_harmony_lane = settings.hide_harmony_lane;
+                ui.checkbox(&mut hide_harmony_lane, "Hide Guitar Notes");
+                if settings.hide_harmony_lane != hide_harmony_lane {
+                    settings.hide_harmony_lane = hide_harmony_lane;
+                    Control::reload_tab(state, theme);
+                }
                 let mut hide_shapes_lane = settings.hide_shapes_lane;
                 ui.checkbox(&mut hide_shapes_lane, "Hide Guitar Chords");
                 if settings.hide_shapes_lane != hide_shapes_lane {
@@ -186,22 +192,17 @@ impl ControlPanel {
                     Control::reload_tab(state, theme);
                 }
                 ui.separator();
-                let show_guitar_syllable = settings.show_guitar_syllable;
-                ui.checkbox(&mut settings.show_guitar_syllable, "Show Guitar Syllable");
-                if show_guitar_syllable != settings.show_guitar_syllable {
-                    Control::reload_tab(state, theme);
-                }
-                let show_melody_syllable = settings.show_melody_syllable;
-                ui.checkbox(&mut settings.show_melody_syllable, "Show Melody Syllable");
-                if show_melody_syllable != settings.show_melody_syllable {
-                    Control::reload_tab(state, theme);
-                }
-                let show_syllable_as_pitch = settings.show_syllable_as_pitch;
+                let show_note_pitch = settings.show_note_pitch;
                 ui.checkbox(
-                    &mut settings.show_syllable_as_pitch,
-                    "Show Syllable as Pitches",
+                    &mut settings.show_note_pitch,
+                    "Show Note Pitch",
                 );
-                if show_syllable_as_pitch != settings.show_syllable_as_pitch {
+                if show_note_pitch != settings.show_note_pitch {
+                    Control::reload_tab(state, theme);
+                }
+                let show_note_syllable = settings.show_note_syllable;
+                ui.checkbox(&mut settings.show_note_syllable, "Show Note Syllable");
+                if show_note_syllable != settings.show_note_syllable {
                     Control::reload_tab(state, theme);
                 }
                 let show_syllable_as_num = settings.show_syllable_as_num;
@@ -217,6 +218,11 @@ impl ControlPanel {
                 if hide_bar_number != settings.hide_bar_number {
                     Control::reload_tab(state, theme);
                 }
+                let hide_indicators = settings.hide_indicators;
+                ui.checkbox(&mut settings.hide_indicators, "Hide Indicators");
+                if hide_indicators != settings.hide_indicators {
+                    Control::reload_tab(state, theme);
+                }
                 let always_show_fret = settings.always_show_fret;
                 ui.checkbox(&mut settings.always_show_fret, "Always Show Fret");
                 if always_show_fret != settings.always_show_fret {
@@ -311,17 +317,24 @@ impl ControlPanel {
     }
     pub fn tab_ui(
         ui: &mut Ui,
-        pathes: &mut TabPathes,
+        args: &mut NotationArgs,
         state: &mut NotationState,
         _settings: &mut NotationSettings,
         theme: &mut NotationTheme,
     ) {
         if theme._bypass_systems {
-            ui.label("Loading Tab ...");
-            return;
+            if state.tab_error.is_some() {
+                ui.label("Load Tab Failed");
+                ui.separator();
+                ui.label(format!("{:?}", state.tab_error.as_ref().unwrap()));
+            } else {
+                ui.label("Loading Tab ...");
+            }
+            ui.separator();
         }
         ui.horizontal(|ui| {
             if ui.button("Reload Tab").clicked() {
+                state.bars_range = None;
                 Control::reload_tab(state, theme);
             }
             ui.separator();
@@ -339,7 +352,7 @@ impl ControlPanel {
                     {
                         let path_str = path.clone().into_os_string().into_string();
                         if let Ok(path_str) = path_str {
-                            pathes.0.insert(0, path_str.clone());
+                            args.tab.insert(0, path_str.clone());
                             state.change_tab(theme, path_str.clone());
                         } else {
                             println!(
@@ -351,13 +364,13 @@ impl ControlPanel {
                 }
             });
         });
-        if pathes.0.len() > 1 {
+        if args.tab.len() > 1 {
             let width = Self::calc_width(state.window_width);
             egui::ComboBox::from_id_source("tab")
                 .selected_text(state.tab_path.clone())
                 .width(width - 24.0)
                 .show_ui(ui, |ui| {
-                    for path in pathes.0.iter() {
+                    for path in args.tab.iter() {
                         if ui.selectable_label(*path == state.tab_path, path).clicked() {
                             state.change_tab(theme, path.clone());
                         }
@@ -605,10 +618,31 @@ impl ControlPanel {
             ui.separator();
         }
     }
+    pub fn presets_ui(
+        ui: &mut Ui,
+        state: &mut NotationState,
+        settings: &mut NotationSettings,
+        theme: &mut NotationTheme,
+        windows: &mut Windows,
+        window_resized_evts: &mut EventWriter<WindowResizedEvent>,
+    ) {
+        CollapsingHeader::new(format!(
+            "Preset: {}",
+            state.preset.clone().unwrap_or("".to_string())
+        ))
+        .default_open(true)
+        .show(ui, |ui| {
+            for preset in Control::ALL_PRESETS.iter() {
+                if ui.button(*preset).clicked() {
+                    Control::set_preset(state, settings, theme, windows, window_resized_evts, *preset);
+                }
+            }
+        });
+    }
     pub fn control_ui(
         egui_ctx: Res<EguiContext>,
         mut windows: ResMut<Windows>,
-        mut pathes: ResMut<TabPathes>,
+        mut args: ResMut<NotationArgs>,
         mut state: ResMut<NotationState>,
         mut settings: ResMut<NotationSettings>,
         mut theme: ResMut<NotationTheme>,
@@ -637,12 +671,14 @@ impl ControlPanel {
                     }
                     ui.separator();
                      */
-                    Self::tab_ui(ui, &mut pathes, &mut state, &mut settings, &mut theme);
+                    Self::tab_ui(ui, &mut args, &mut state, &mut settings, &mut theme);
                     ui.separator();
                     #[cfg(feature = "midi")]
                     {
                         Self::play_control_ui(
                             ui,
+                            &mut state,
+                            &mut theme,
                             &mut settings,
                             &mut midi_state,
                             &mut play_control_evts,
@@ -700,6 +736,8 @@ impl ControlPanel {
                                 *theme = NotationTheme::default();
                                 Control::reload_tab(&mut state, &mut theme);
                             }
+                            ui.separator();
+                            Self::presets_ui(ui, &mut state, &mut settings, &mut theme, &mut windows, &mut window_resized_evts);
                         });
                     });
                 });
