@@ -13,6 +13,7 @@ pub fn create_tone_notes(
     assets: &NotationAssets,
     theme: &NotationTheme,
     settings: &NotationSettings,
+    tone_mode: ToneMode,
     entity: Entity,
     entry: &LaneEntry,
     tone: &Tone,
@@ -29,15 +30,21 @@ pub fn create_tone_notes(
         for note in tone.get_notes() {
             let data = ToneNoteData::new(entry, ToneNoteValue::new(&bar, note, mode));
             let note_entity = data.create(commands, theme, entity);
-            if settings.show_melody_syllable && !entry.prev_is_tie() {
-                theme.texts.melody.spawn_syllable_text(
-                    commands,
-                    note_entity,
-                    assets,
-                    settings,
-                    &meta.scale, &meta.key,
-                    &data.value.syllable(),
-                )
+            if settings.show_note_text() && !entry.prev_is_tie() {
+                if let Some(text) = match tone_mode {
+                    ToneMode::Melody => Some(theme.texts.melody),
+                    ToneMode::Harmony => Some(theme.texts.harmony),
+                    _ => None,
+                } {
+                    text.spawn_note_text(
+                        commands,
+                        note_entity,
+                        assets,
+                        settings,
+                        &meta.scale, &meta.key,
+                        &data.value.syllable(),
+                    )
+                }
             }
         }
     }
